@@ -27,6 +27,13 @@
 #include <stdio.h>
 #include <dirent.h>
 
+#ifdef __FreeBSD__
+#include <sys/file.h>
+#include <sys/ioctl.h>
+#include <sys/types.h>
+#include <machine/apm_bios.h>
+#endif
+
 YColor *YApm::apmBg = 0;
 YColor *YApm::apmFg = 0;
 ref<YFont> YApm::apmFont;
@@ -48,8 +55,12 @@ static YColor *taskBarBg = 0;
 
 
 void ApmStr(char *s, bool Tool) {
+#ifdef __FreeBSD__
+    struct apm_info ai;
+#else
     char buf[80];
-    int len, i, fd = open("/proc/apm", O_RDONLY);
+#endif
+    int len, i, fd = open(APMDEV, O_RDONLY);
     char driver[16];
     char apmver[16];
     int apmflags;
@@ -61,9 +72,31 @@ void ApmStr(char *s, bool Tool) {
     char units[16];
 
     if (fd == -1) {
+        static int error = 0;
+        if (!error)
+            perror("Can't open the apm device");
+        error = 1;
         return ;
     }
+#ifdef __FreeBSD__
+    if (ioctl(fd,APMIO_GETINFO, &ai) == -1)
+    {
+        static int error = 0;
+        if (!error)
+            perror("Can't ioctl the apm device");
+        error = 1;
+        close(fd);
+        return;
+    }
+    close(fd);
 
+    sprintf(apmver, "%u.%u", ai.ai_major, ai.ai_minor);
+    ACstatus = ai.ai_acline;
+    BATflag = ai.ai_batt_stat == 3 ? 8 : 0;
+    BATlife = ai.ai_batt_life;
+    BATtime = ai.ai_batt_time == 0 ? -1 : ai.ai_batt_time;
+    strcpy(units, "sec");
+#else
     len = read(fd, buf, sizeof(buf) - 1);
     close(fd);
 
@@ -77,10 +110,11 @@ void ApmStr(char *s, bool Tool) {
         static int error = 1;
         if (error) {
             error = 0;
-            warn(_("/proc/apm - unknown format (%d)"), i);
+            warn(_("%s - unknown format (%d)"), APMDEV, i);
         }
         return ;
     }
+#endif
     if (BATlife == -1)
         BATlife = 0;
 
@@ -168,6 +202,8 @@ void YApm::AcpiStr(char *s, bool Tool) {
     int BATstatus;
     //maximal battery capacity (mWh)
     int BATcapacity_full;
+    //design capacity (mAh)
+    int BATcapacity_design;
     //current battery capacity (mWh)
     int BATcapacity_remain;
     //how much energy is used atm (mW)
@@ -183,32 +219,34 @@ void YApm::AcpiStr(char *s, bool Tool) {
     //assign some default values, in case
     //the file in /proc/acpi will contain unexpected values
     ACstatus = -1;
-    strcat3(buf, "/proc/acpi/ac_adapter/", acpiACName, "/state", sizeof(buf));
-    fd = fopen(buf, "r");
-    if (fd == NULL) {
-        //try older /proc/acpi format
-        strcat3(buf, "/proc/acpi/ac_adapter/", acpiACName, "/status", sizeof(buf));
+    if (acpiACName && acpiACName[0] != 0) {
+        strcat3(buf, "/proc/acpi/ac_adapter/", acpiACName, "/state", sizeof(buf));
         fd = fopen(buf, "r");
-    }
-    if (fd != NULL) {
-        while (fgets(buf, sizeof(buf), fd)) {
-            if ((strncasecmp(buf, "state:", 6) == 0 &&
-                 sscanf(buf + 6, "%s", buf2) > 0) ||
-                //older /proc/acpi format
-                (strncasecmp(buf, "Status:", 7) == 0 &&
-                 sscanf(buf + 7, "%s", buf2) > 0)) {
-                if (strncasecmp(buf2, "on-line", 7) == 0) {
-                    ACstatus = AC_ONLINE;
-                }
-                else if (strncasecmp(buf2, "off-line", 8) == 0) {
-                    ACstatus = AC_OFFLINE;
-                }
-                else {
-                    ACstatus = AC_UNKNOWN;
+        if (fd == NULL) {
+            //try older /proc/acpi format
+            strcat3(buf, "/proc/acpi/ac_adapter/", acpiACName, "/status", sizeof(buf));
+            fd = fopen(buf, "r");
+        }
+        if (fd != NULL) {
+            while (fgets(buf, sizeof(buf), fd)) {
+                if ((strncasecmp(buf, "state:", 6) == 0 &&
+                     sscanf(buf + 6, "%s", buf2) > 0) ||
+                    //older /proc/acpi format
+                    (strncasecmp(buf, "Status:", 7) == 0 &&
+                     sscanf(buf + 7, "%s", buf2) > 0)) {
+                    if (strncasecmp(buf2, "on-line", 7) == 0) {
+                        ACstatus = AC_ONLINE;
+                    }
+                    else if (strncasecmp(buf2, "off-line", 8) == 0) {
+                        ACstatus = AC_OFFLINE;
+                    }
+                    else {
+                        ACstatus = AC_UNKNOWN;
+                    }
                 }
             }
+            fclose(fd);
         }
-        fclose(fd);
     }
 
     for (i = 0; i < batteryNum; i++) {
@@ -218,6 +256,7 @@ void YApm::AcpiStr(char *s, bool Tool) {
         BATpresent = -1;
         BATstatus = -1;
         BATcapacity_full = -1;
+	BATcapacity_design = -1;
         BATcapacity_remain = -1;
         BATrate = -1;
         BATtime_remain = -1;
@@ -270,7 +309,7 @@ void YApm::AcpiStr(char *s, bool Tool) {
             }
             fclose(fd);
         }
-        
+
         if (BATpresent == BAT_PRESENT) { //battery is present now
             if (acpiBatteries[i]->present == BAT_ABSENT) { //and previously was absent
                 //read full-capacity value
@@ -278,14 +317,22 @@ void YApm::AcpiStr(char *s, bool Tool) {
                 fd = fopen(buf, "r");
                 if (fd != NULL) {
                     while (fgets(buf, sizeof(buf), fd)) {
+                        if (strncasecmp(buf, "design capacity:", 16) == 0) {
+                            //may contain non-numeric value
+                            if (sscanf(buf, "%*[^0-9]%d", &BATcapacity_design)<=0) {
+                                BATcapacity_design = -1;
+                            }
+                        }
                         if (strncasecmp(buf, "last full capacity:", 19) == 0) {
                             //may contain non-numeric value
-                            if (sscanf(buf + 19, "%d", &BATcapacity_full)<=0) {
+                            if (sscanf(buf, "%*[^0-9]%d", &BATcapacity_full)<=0) {
                                 BATcapacity_full = -1;
                             }
                         }
                     }
                     fclose(fd);
+		    if (BATcapacity_remain > BATcapacity_full && BATcapacity_design > 0)
+			BATcapacity_full = BATcapacity_design;
                 }
 		acpiBatteries[i]->capacity_full	= BATcapacity_full;
             }
@@ -348,6 +395,9 @@ YApm::YApm(YWindow *aParent): YWindow(aParent) {
     struct dirent **de;
     int n, i;
 
+    batteryNum = 0;
+    acpiACName = 0;
+
     //search for acpi info first
     n = scandir("/proc/acpi/battery", &de, 0, alphasort);
     if (n > 0) {
@@ -355,7 +405,6 @@ YApm::YApm(YWindow *aParent): YWindow(aParent) {
         acpiMode = 1;
 
         //scan for batteries
-        batteryNum = 0;
         i = 0;
         while (i < n && batteryNum < MAX_ACPI_BATTERY_NUM) {
             if (!ignore_directory_bat_entry(de[i])) {
@@ -378,25 +427,25 @@ YApm::YApm(YWindow *aParent): YWindow(aParent) {
 
         //scan for first ac_adapter
         n = scandir("/proc/acpi/ac_adapter", &de, 0, alphasort);
-        i = 0; acpiACName = 0;
-        while (i < n) {
-            if (!ignore_directory_entry(de[i])) {
-                //found an ac_adapter
-                acpiACName = (char*)calloc(strlen(de[i]->d_name) + 1, sizeof(char));
-                strcpy(acpiACName, de[i]->d_name);
-                break;
+        if (n > 0) {
+            i = 0;
+            while (i < n) {
+                if (!ignore_directory_entry(de[i])) {
+                    //found an ac_adapter
+                    acpiACName = (char*)calloc(strlen(de[i]->d_name) + 1, sizeof(char));
+                    strcpy(acpiACName, de[i]->d_name);
+                    break;
+                }
+                free(de[i]);
+                i++;
             }
-            free(de[i]);
-            i++;
+            free(de);
         }
         if (!acpiACName) {
             //no ac_adapter was found
             acpiACName = (char*)malloc(sizeof(char));
             *acpiACName = '\0';
         }
-        else {
-        }
-        free(de);
 
     }
     else {
