@@ -171,12 +171,12 @@ inline bool strIsEmpty(char const *str) {
 int strpcmp(char const *str, char const *pfx, char const *delim = "=:");
 unsigned strtoken(const char *str, const char *delim = " \t");
 char const * strnxt(const char *str, const char *delim = " \t");
-extern "C" char *basename(const char *filename);
+
+const char *my_basename(const char *filename);
 
 bool strequal(const char *a, const char *b);
 int strnullcmp(const char *a, const char *b);
 
-
 #if 0
 inline char *strlower(char *str) {
     for (char *c = str; *c; ++c) *c = TOLOWER(*c);
