@@ -11,6 +11,10 @@
 #include "intl.h"
 #include "ref.h"
 
+#ifdef HAVE_LIBGEN_H 
+#include <libgen.h>
+#endif
+
 extern char const *ApplicationName;
 
 #ifdef DEBUG
@@ -448,11 +452,15 @@ unsigned strtoken(const char * str, const char * delim) {
     return count;	     
 }
 
-#ifndef HAVE_BASENAME
-extern "C" char *basename(const char *path) {
-    char *base = ::strrchr(path, DIR_DELIMINATOR);
+#if 1
+const char *my_basename(const char *path) {
+    const char *base = ::strrchr(path, DIR_DELIMINATOR);
     return (base ? base + 1 : path);
 }
+#else
+const char *my_basename(const char *path) {
+    return basename(path);
+}
 #endif
 
 bool strequal(const char *a, const char *b) {
