@@ -1120,7 +1120,7 @@ YWMApp::YWMApp(int *argc, char ***argv, const char *displayName):
     hintOptions = new WindowOptions();
     if (winOptFile)
         loadWinOptions(winOptFile);
-    delete winOptFile; winOptFile = 0;
+    delete[] winOptFile; winOptFile = 0;
 #endif
 
 #ifndef NO_CONFIGURE_MENUS
@@ -1474,7 +1474,7 @@ int main(int argc, char **argv) {
             else if (IS_SWITCH("v", "version"))
                 print_version();
             else if (IS_SWITCH("h", "help"))
-                print_usage(basename(argv[0]));
+                print_usage(my_basename(argv[0]));
 #endif
         }
     }
