@@ -707,8 +707,10 @@ void YFrameClient::handleClientMessage(const XClientMessageEvent &message) {
 #ifdef WMSPEC_HINTS
     if (message.message_type == _XA_NET_ACTIVE_WINDOW) {
         //printf("active window w=0x%lX\n", message.window);
-        if (getFrame())
+        if (getFrame()) {
             getFrame()->activate();
+            getFrame()->wmRaise();
+        }
     } else if (message.message_type == _XA_NET_CLOSE_WINDOW) {
         //printf("close window w=0x%lX\n", message.window);
         if (getFrame())
@@ -767,7 +769,7 @@ void YFrameClient::handleClientMessage(const XClientMessageEvent &message) {
             setWinWorkspaceHint(message.data.l[0]);
     } else if (message.message_type == _XA_NET_WM_DESKTOP) {
         if (getFrame()) {
-            if (message.data.l[0] == 0xFFFFFFFF)
+            if ((unsigned long)message.data.l[0] == 0xFFFFFFFFUL)
                 getFrame()->setSticky(true);
             else
                 getFrame()->setWorkspace(message.data.l[0]);
