@@ -305,6 +305,7 @@ public:
 #endif
 
     void getNormalGeometry(int *x, int *y, int *w, int *h);
+    void setNormalGeometry(int x, int y, int w, int h);
     void setCurrentGeometry(YRect newSize);
     void updateNormalSize();
     void updateMaximizedSize();
@@ -527,9 +528,18 @@ private:
         waRight
     };
     void wmArrange(int tcb, int lcr);
+    void wmSnapMove(int tcb, int lcr);
+    int getTopCoord(int my, YFrameWindow **w, int count);
+    int getBottomCoord(int My, YFrameWindow **w, int count);
+    int getLeftCoord(int mx, YFrameWindow **w, int count);
+    int getRightCoord(int Mx, YFrameWindow **w, int count);
 
     // only focus if mouse moves
     int fMouseFocusX, fMouseFocusY;
+
+    void setGeometry(const YRect &r) {
+        YWindow::setGeometry(r);
+    }
 };
 
 //!!! remove this
