@@ -68,6 +68,7 @@ YWindowManager::YWindowManager(YWindow *parent, Window win):
     fWorkAreaMoveWindows = false;
     fWorkArea = 0;
     fWorkAreaCount = 0;
+    fFullscreenEnabled = true;
 
     frameContext = XUniqueContext();
     clientContext = XUniqueContext();
@@ -188,6 +189,8 @@ void YWindowManager::grabKeys() {
     GRAB_WMKEY(gKeySysMinimizeAll);
     GRAB_WMKEY(gKeySysHideAll);
 
+    GRAB_WMKEY(gKeySysShowDesktop);
+
 #ifndef NO_CONFIGURE_MENUS
     {
         KProgram *k = keyProgs;
@@ -473,6 +476,10 @@ bool YWindowManager::handleWMKey(const XKeyEvent &key, KeySym k, unsigned int /*
         ///        } else if (IS_WMKEY(k, vm, gKeySysRun)) {
         ///            if (runDlgCommand && runDlgCommand[0])
         ///                app->runCommand(runDlgCommand);
+    } else if(IS_WMKEY(k, vm, gKeySysShowDesktop)) {
+        XAllowEvents(xapp->display(), AsyncKeyboard, key.time);
+        wmapp->actionPerformed(actionShowDesktop, 0);
+        return true;				
     } else {
 #ifndef NO_CONFIGURE_MENUS
         KProgram *p = keyProgs;
@@ -520,8 +527,10 @@ bool YWindowManager::handleKey(const XKeyEvent &key) {
             if (k == xapp->Win_L || k == xapp->Win_R) {
                 /// !!! needs sync grab
                 XAllowEvents(xapp->display(), ReplayKeyboard, key.time);
+                return true;
             }
         }
+        XAllowEvents(xapp->display(), SyncKeyboard, key.time);
     }
     return true;
 }
@@ -1347,7 +1356,7 @@ void YWindowManager::placeWindow(YFrameWindow *frame, int x, int y,
 
 setGeo:
     MSG(("mapping geometry (%d:%d %dx%d)", posX, posY, posWidth, posHeight));
-    frame->setGeometry(YRect(posX, posY, posWidth, posHeight));
+    frame->setNormalGeometry(posX, posY, posWidth, posHeight);
 
 }
 
@@ -1418,6 +1427,8 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
     if (client->visible() && wmState() == wmSTARTUP)
         mapClient = true;
 
+    manager->updateFullscreenLayerEnable(false);
+
     frame = new YFrameWindow(0);
     if (frame == 0) {
         delete client;
@@ -1467,7 +1478,7 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
         posY -= frame->borderY();
         posWidth += 2 * frame->borderX();
         posHeight += 2 * frame->borderY();
-        frame->setGeometry(YRect(posX, posY, posWidth, posHeight));
+        frame->setNormalGeometry(posX, posY, posWidth, posHeight);
     }
 
     if (!mapClient) {
@@ -1489,7 +1500,8 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
         canManualPlace = true;
 
     if (mapClient) {
-        if (frame->getState() == 0 || frame->isRollup()) {
+        if (!(frame->getState() & (WinStateHidden | WinStateMinimized | WinStateFullscreen)))
+        {
             if (canManualPlace && !opaqueMove)
                 frame->manualPlace();
         }
@@ -1504,7 +1516,8 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
     if (frame->affectsWorkArea())
 	updateWorkArea();
     if (mapClient) {
-        if (frame->getState() == 0 || frame->isRollup()) {
+        if (!(frame->getState() & (WinStateHidden | WinStateMinimized)))
+        {
             if (wmState() == wmRUNNING && canActivate)
                 frame->focusOnMap();
             if (canManualPlace && opaqueMove)
@@ -1522,7 +1535,7 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
 #endif
     }
 #endif
-
+    manager->updateFullscreenLayerEnable(true);
 end:
     XUngrabServer(xapp->display());
     return frame;
@@ -1710,9 +1723,13 @@ YFrameWindow *YWindowManager::bottomLayer(long layer) {
     return 0;
 }
 
+void YWindowManager::updateFullscreenLayerEnable(bool enable) {
+    fFullscreenEnabled = enable;
+    updateFullscreenLayer();
+}
+
 void YWindowManager::updateFullscreenLayer() { /// HACK !!!
     YFrameWindow *w = topLayer();
-
     while (w) {
         if (w->getActiveLayer() == WinLayerFullscreen ||
             w->isFullscreen())
@@ -1849,7 +1866,7 @@ void YWindowManager::restackWindows(YFrameWindow *win) {
         MSG(("i=%d, count=%d", i, count));
     }
     PRECONDITION(i == count);
-    delete w;
+    delete[] w;
 }
 
 void YWindowManager::getWorkArea(const YFrameWindow *frame,
@@ -2509,7 +2526,7 @@ void YWindowManager::tilePlace(YFrameWindow *w, int tx, int ty, int tw, int th)
                                0);
     tw += 2 * w->borderX();
     th += 2 * w->borderY() + w->titleY();
-    w->setGeometry(YRect(tx, ty, tw, th));
+    w->setNormalGeometry(tx, ty, tw, th);
 }
 
 void YWindowManager::tileWindows(YFrameWindow **w, int count, bool vertical) {
@@ -2638,10 +2655,10 @@ void YWindowManager::undoArrange() {
             YFrameWindow *f = fArrangeInfo[i].frame;
             if (f) {
                 f->setState(WIN_STATE_ALL, fArrangeInfo[i].state);
-                f->setGeometry(YRect(fArrangeInfo[i].x,
+                f->setNormalGeometry(fArrangeInfo[i].x,
                                      fArrangeInfo[i].y,
                                      fArrangeInfo[i].w,
-                                     fArrangeInfo[i].h));
+                                     fArrangeInfo[i].h);
             }
         }
         delete [] fArrangeInfo; fArrangeInfo = 0;
