@@ -110,7 +110,9 @@ YWindow::YWindow(YWindow *parent, Window win):
     fEventMask(KeyPressMask|KeyReleaseMask|FocusChangeMask|
 	       LeaveWindowMask|EnterWindowMask),
     fWinGravity(NorthWestGravity), fBitGravity(ForgetGravity),
-    fEnabled(true), fToplevel(false), accel(0),
+    fEnabled(true), fToplevel(false),
+    fDoubleBuffer(doubleBuffer),
+    accel(0),
 #ifdef CONFIG_TOOLTIP
     fToolTip(0),
 #endif
@@ -125,8 +127,6 @@ YWindow::YWindow(YWindow *parent, Window win):
         fParentWindow = desktop;
     }
     insertWindow();
-    if (doubleBuffer)
-        fStyle |= wsDoubleBuffer;
 }
 
 YWindow::~YWindow() {
@@ -637,7 +637,7 @@ void YWindow::endPaint(Graphics &g, ref<YPixmap> pixmap, YRect &r) {
 }
 
 void YWindow::setDoubleBuffer(bool doubleBuffer) {
-    fStyle = (fStyle & ~wsDoubleBuffer) | (doubleBuffer ? wsDoubleBuffer : 0);
+    fDoubleBuffer = doubleBuffer;
 }
 
 #warning "implement expose compression"
@@ -681,7 +681,7 @@ void YWindow::paintExpose(int ex, int ey, int ew, int eh) {
 
 
     YRect r1(ex, ey, ew, eh);
-    if (fStyle & wsDoubleBuffer) {
+    if (fDoubleBuffer) {
         ref<YPixmap> pixmap = beginPaint(r1);
         Graphics g1(pixmap, ex, ey);
         paint(g1, r1);
@@ -1540,7 +1540,7 @@ YDesktop::YDesktop(YWindow *aParent, Window win):
     YWindow(aParent, win)
 {
     desktop = this;
-    setDoubleBuffer(0);
+    setDoubleBuffer(false);
     updateXineramaInfo();
 }
 
