@@ -10,6 +10,9 @@
 
 static YColor *trayBg;
 
+// make this configurable
+#define TRAY_ICON_SIZE 24
+
 class YXTrayProxy: public YWindow {
 public:
     YXTrayProxy(const char *atom, YXTray *tray, YWindow *aParent = 0);
@@ -116,19 +119,26 @@ YXTray::~YXTray() {
 void YXTray::trayRequestDock(Window win) {
     MSG(("trayRequestDock"));
 
+    destroyedClient(win);
     YXEmbedClient *client = new YXEmbedClient(this, this, win);
 
-    MSG(("size %d %d", client->width(), client->height()));
+    msg("size %d %d", client->width(), client->height());
 
     XSetWindowBorderWidth(xapp->display(),
                           client->handle(),
                           0);
 
     if (!fInternal) {
-        if (client->width() <= 1 && client->height() <= 1)
-            client->setSize(24, 24);
-        if (client->width() > 256 || client->height() > 48)
-            client->setSize(24, 24);
+        int ww = client->width();
+        int hh = client->height();
+
+        // !!! hack, hack
+        if (ww < 16 || ww > 8 * TRAY_ICON_SIZE)
+            ww = TRAY_ICON_SIZE;
+        if (hh < 16 || hh > TRAY_ICON_SIZE)
+            hh = TRAY_ICON_SIZE;
+
+        client->setSize(ww, hh);
     }
          
     XAddToSaveSet(xapp->display(), client->handle());
@@ -151,13 +161,13 @@ void YXTray::destroyedClient(Window win) {
             break;
         }
     }
-///    msg("remain %d", fDocked.getCount());
     relayout();
 }
 
 void YXTray::handleConfigureRequest(const XConfigureRequestEvent &configureRequest)
 {
     MSG(("tray configureRequest"));
+    msg("%d %d", configureRequest.width, configureRequest.height);
     bool changed = false;
     for (unsigned int i = 0; i < fDocked.getCount(); i++) {
         YXEmbedClient *ec = fDocked[i];
@@ -241,6 +251,8 @@ void YXTray::relayout() {
         YXEmbedClient *ec = fDocked[i];
         ec->show();
     }
+
+    msg("clients %d width: %d", fDocked.getCount(), width());
 }
 
 bool YXTray::kdeRequestDock(Window win) {
